@@ -518,6 +518,8 @@ class RawTextRfcWriter(BaseRfcWriter):
             heading.append(xml2rfc.utils.justify_inline(left, '', right, \
                                                         self.width))
         self.write_raw('\n'.join(heading), align='left', indent=0, lb=False)
+        # Extra blank line underneath top block
+        self._lb()
 
     def write_address_card(self, author):
         """ Writes a simple address card with no line breaks """
@@ -540,15 +542,15 @@ class RawTextRfcWriter(BaseRfcWriter):
                 cityline = []
                 city = postal.find('city')
                 if city is not None and city.text:
-                        cityline.append(city.text)
-                        cityline.append(', ')
+                    cityline.append(city.text)
                 region = postal.find('region')
                 if region is not None and region.text:
-                        cityline.append(region.text)
-                        cityline.append(' ')
+                    if len(cityline) > 0: cityline.append(', ');
+                    cityline.append(region.text)
                 code = postal.find('code')
                 if code is not None and code.text:
-                        cityline.append(code.text)
+                    if len(cityline) > 0: cityline.append(' ');
+                    cityline.append(code.text)
                 if len(cityline) > 0:
                     lines.append(''.join(cityline))
                 country = postal.find('country')
@@ -563,7 +565,8 @@ class RawTextRfcWriter(BaseRfcWriter):
                 lines.append('Fax:   ' + fascimile.text)
             email = address.find('email')
             if email is not None and email.text:
-                lines.append('Email: ' + email.text)
+                label = self.pis.get('rfcedstyle', 'no') == 'yes' and 'EMail' or 'Email'
+                lines.append('%s: %s' % (label, email.text))
             uri = address.find('uri')
             if uri is not None and uri.text:
                 lines.append('URI:   ' + uri.text)
